diff -r 058a5d7a4f84 tools/data_source/upload.py
--- a/tools/data_source/upload.py	Mon Jun 06 09:08:59 2011 -0400
+++ b/tools/data_source/upload.py	Mon Jul 25 17:04:08 2011 +0200
@@ -4,19 +4,27 @@
 # WARNING: Changes in this tool (particularly as related to parsing) may need
 # to be reflected in galaxy.web.controllers.tool_runner and galaxy.tools
 
-import urllib, sys, os, gzip, tempfile, shutil, re, gzip, zipfile, codecs, binascii
+import urllib, sys, os, gzip, tempfile, shutil, re, gzip, zipfile, codecs, binascii, imghdr
 from galaxy import eggs
 # need to import model before sniff to resolve a circular import dependency
 import galaxy.model
 from galaxy.datatypes.checkers import *
 from galaxy.datatypes import sniff
 from galaxy.datatypes.binary import *
-from galaxy.datatypes.images import Pdf
+from galaxy.datatypes.images import Pdf, Image
 from galaxy.datatypes.registry import Registry
 from galaxy import util
 from galaxy.util.json import *
 
 try:
+    import Image as PIL
+except ImportError:
+    try:
+        from PIL import Image as PIL
+    except:
+        PIL = None
+
+try:
     import bz2
 except:
     bz2 = None
@@ -58,6 +66,57 @@
 def check_pdf( file_path ):
     return Pdf().sniff( file_path )
 
+def check_image( file_path ):
+    if PIL != None:
+        try:
+            im = PIL.open( file_path )
+        except:
+            return False
+        if im:
+            return im
+        return False
+    else:
+        if imghdr.what(file_path) != None:
+            return True
+        return False
+    
+def get_image_ext ( file_path, im ):
+    #determine ext
+    format = Image().image_type( file_path, im )    
+    if format in ['JPG','JPEG']:
+        return 'jpg'
+    if format == 'PNG':
+        return 'png'
+    if format == 'TIFF':
+        return 'tiff'
+    if format == 'BMP':
+        return 'bmp'
+    if format == 'GIF':
+        return 'gif'
+    if format == 'IM':
+        return 'im'
+    if format == 'PCD':
+        return 'pcd'
+    if format == 'PCX':
+        return 'pcx'
+    if format == 'PPM':
+        return 'ppm'
+    if format == 'PSD':
+        return 'psd'
+    if format == 'XBM':
+        return 'xbm'
+    if format == 'XPM':
+        return 'xpm'
+    if format == 'RGB':
+        return 'rgb'
+    if format == 'PBM':
+        return 'pbm'
+    if format == 'PGM':
+        return 'pgm'
+    if format == 'EPS':
+        return 'eps'
+
+    
 def check_bigwig( file_path ):
     return BigWig().sniff( file_path )
 
@@ -102,10 +161,17 @@
             dataset.is_multi_byte = util.is_multi_byte( codecs.open( dataset.path, 'r', 'utf-8' ).read( 100 ) )
         except UnicodeDecodeError, e:
             dataset.is_multi_byte = False
-    # Is dataset content multi-byte?
+    # Try to open dataset as image
+    image = check_image( dataset.path )
+    # Is dataset content multi-byte?    
     if dataset.is_multi_byte:
         data_type = 'multi-byte char'
         ext = sniff.guess_ext( dataset.path, is_multi_byte=True )
+    elif image:
+        if not PIL or PIL == None:
+            image=None
+        ext = get_image_ext( dataset.path, image )
+        data_type = ext
     # Is dataset content supported sniffable binary?
     elif check_bam( dataset.path ):
         ext = 'bam'
@@ -115,7 +181,7 @@
         data_type = 'sff'
     elif check_pdf( dataset.path ):
         ext = 'pdf'
-        data_type = 'pdf'
+        data_type = 'pdf'    
     elif check_bigwig( dataset.path ):
         ext = 'bigwig'
         data_type = 'bigwig'
